Re: [PATCH 0/3] Make add_missing_tags() linear
- From
Derrick Stolee <stolee@gmail.com>
- Date
- Nov 1, 2018, 19:02 UTC
- Message-ID
- <3aadf261-9ed7-6ded-4482-ab01d74802aa@gmail.com>
- In-Reply-To
- <CABPp-BG6+3F+FY0JP2mj0OCLjp17xQXTe54mBCN+RifQd4Aj2A@mail.gmail.com>
On 11/1/2018 2:57 PM, Elijah Newren wrote:
Show 13 quoted lines
> On Thu, Nov 1, 2018 at 5:32 AM Derrick Stolee <stolee@gmail.com> wrote: >> No rush. I'd just like to understand how removing the commit-graph file >> can make the new algorithm faster. Putting a similar count in the old >> algorithm would involve giving a count for every call to >> in_merge_bases_many(), which would be very noisy. > $ time git push --dry-run --follow-tags /home/newren/repo-mirror > count: 92912 > To /home/newren/repo-mirror > * [new branch] test5 -> test5 > > real 0m3.024s > user 0m2.752s > sys 0m0.320s
Is the above test with or without the commit-graph file? Can you run it in the other mode, too? I'd like to see if the "count" value changes when the only difference is the presence of a commit-graph file.
Thanks, -Stolee